#!/bin/sh -e
#
#   Quickly backup and compress configuration files for ubottu like bots.
#
#   Please see: https://wiki.ubuntu.com/UbuntuBots for more information on the
#   ubottu family.
#
#   Copyright (C) 2009 Jonathan Davies <jpds@ubuntu.com>
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#   1. Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#   
#   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
#   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
#   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
#   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
#   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
#   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# Where our databases and backup directory are located.
backupdir="$HOME/backups/config"
botdir="$HOME/bots/ubot2"
botname="ubot2"

test -d $backupdir || {
    echo "Backup directory $backupdir - does not exist."
    exit 1
}

test -d $dbdir || {
    echo "Bot directory $botdir - does not exist."
    exit 1
}

DATE=$(date -I)

tar --create --gzip --exclude=$botdir/data/apt -f $backupdir/$botname-$DATE-config.tar.gz $botdir

# Purge old database files which are more than a week old.
find $backupdir -name '*.gz' -type f -atime +8 -exec rm -vf {} \; &> /dev/null

# Generate hashes of all tarballs for future reference.
sha1sum $backupdir/* > $backupdir/SHA1SUMS
