#!/usr/bin/python
#
#   config_backups.py: Check that configuration backups are up-to-date.
#
#   Copyright (c) 2009 Jonathan Davies <jpds@ubuntu.com>
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#   1. Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
#   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
#   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
#   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
#   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
#   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

from datetime import datetime, timedelta
import os
import sys
import time

time_now = time.time()

today = datetime.today()
# Get yesterday's date.
yesterday = today - timedelta(1)

date = yesterday.date()

we_are_safe = False

# Backup location.
backup_dir =  os.path.expanduser("backups/config/")

# Check that the back up directory actually exists.
if not os.path.isdir(backup_dir):
    print "CRITICAL: Configuration backup directory does not exist."
    sys.exit(2)

dir_list = os.listdir(backup_dir)

for config_tarball in dir_list:
    tarball_atime = os.path.getatime(backup_dir + config_tarball)

    difference = time_now - tarball_atime

    if difference < 86400:
        we_are_safe = True
        break

if not we_are_safe:
    print "CRITICAL: Configuration backups are not up-to-date."
    sys.exit(2)
else:
    print "OK: Configuration backups are up-to-date."
    sys.exit(0)

