#!/usr/bin/python
#
#   db_backups.py: Check that the database backups are up-to-date.
#
#   Copyright (c) 2009 Jonathan Davies <jpds@ubuntu.com>
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#   1. Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#
#   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
#   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
#   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
#   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
#   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
#   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

import datetime
import os
import sys
import time
from optparse import OptionParser

debug = 0
time_now = time.time()

usage = "%prog [--debug]"

option_parser = OptionParser(usage)

option_parser.add_option("--debug", dest = "debug", action = "store_true",
    help = "Whether information about which files are being "
        "probed should be displayed")

(options, args) = option_parser.parse_args()

if options.debug:
    debug = True

backup_dir = os.path.expanduser("backups/databases/")

backup_dir_list = os.listdir(backup_dir)

# This should always stay empty.
outdated_backups = []

for directory in backup_dir_list:
    # Make sure the 'directory' feed to us is a directory.
    if not os.path.isdir(backup_dir + directory):
        if debug:
            print "WARNING: %s is not a directory." % (backup_dir + directory)
        continue

    dir_list = os.listdir(backup_dir + directory)

    if len(dir_list) == 0:
        print "CRITICAL: Database backup directory for %s is empty." % \
            directory
        sys.exit(2)

    for db in dir_list:
        current_file = backup_dir + directory + "/" + db

        if debug:
            print "Probing: " + current_file

        db_atime = os.path.getatime(current_file)
    
        difference = time_now - db_atime
    
        # Check if it's older than 24 hours.
        if difference < 86400:
            if directory in outdated_backups:
                outdated_backups.remove(directory)
            break
        else:
            # Backups out-of-date - append to listing.
            outdated_backups.append(directory)

            if debug:
                print "Appending to blacklist: %s." % directory
                print " - No files younger than 24 hours were found."

if len(outdated_backups) != 0:
    print "CRITICAL: Database backups for %s are not up-to-date." % \
        ", ".join(outdated_backups)
    sys.exit(2)
else:
    print "OK: Database backups are up-to-date as of %s." % \
        datetime.datetime.utcnow()
    sys.exit(0)
