#!/bin/sh -e
#
#   Quickly sync remote database files for ubottu like bots.
#
#   Please see: https://wiki.ubuntu.com/UbuntuBots for more information on the
#   ubottu family.
#
#   Copyright (C) 2009 Jonathan Davies <jpds@ubuntu.com>
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#   1. Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#   2. Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#   
#   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
#   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
#   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
#   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
#   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
#   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

logfile="$HOME/last-db-sync"
synclock="$HOME/sync-lock.$(hostname -f)"
rsyncoutput="$HOME/rsync-log"
dblocation="$HOME/bots/*/data/factoids/ubuntu.db"
remotedb="rsync://ubottu.com/ubottu/ubuntu.db"

# Check to see if another sync is in progress
if ! ( set -o noclobber; echo "$$" > "${synclock}") 2> /dev/null; then
    if ! $(kill -0 $(cat ${synclock}) 2>/dev/null); then
        # Process does either not exist or is not owned by us.
        echo "$$" > "${synclock}"
    else
        echo "Unable to start rsync, lock file still exists, PID $(cat ${synclock})."
        exit 1
    fi
fi

echo "Last database update took place at:" > $logfile

# Run rsync and write stats to log.
rsync --archive --compress --human-readable --partial --stats \
  $remotedb $dblocation >> $rsyncoutput

# Write dates to log file now that sync is done.
echo "" >> $logfile
echo " * $(date)" >> $logfile
echo " * $(date -u)" >> $logfile

# Now put rsync output in log.
cat $rsyncoutput >> $logfile
rm -f $rsyncoutput

# List file details into log file.
echo "\nDatabase is:" >> $logfile
ls -l $dblocation >> $logfile

# Check if old log file exists - if so delete it.
test -f $logfile.gz && rm -f $logfile.gz

# Compress log file.
gzip -9 $logfile

# Remove lock file.
rm -f $synclock
